API Documentation
=================

Data Structures
---------------

.. toctree:: pykoala.data_container
   :titlesonly:

.. _supported_instruments:

Supported IFS Instruments
^^^^^^^^^^^^^^^^^^^^^^^^^

The currently available instrument modules in `pykoala` are:

- :class:`pykoala.instruments.koala_ifu`
- :class:`pykoala.instruments.weave`
- :class:`pykoala.instruments.mock`

Data Corrections
----------------
 
Correction modules included in `pykoala`.

.. toctree:: pykoala.corrections
   :maxdepth: 1

Cubing
------

Interpolation of RSS data into 3D datacubes.


.. toctree:: pykoala.cubing
   :maxdepth: 1


Plotting tools
--------------

Auxiliary methods for plotting and performing quality control tests.

.. toctree:: pykoala.plotting
   :titlesonly:
